pub struct CreateNotebookFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateNotebook.
Creates a notebook in Amazon SageMaker Unified Studio. A notebook is a collaborative document within a project that contains code cells for interactive computing.
Implementations
Sourceimpl CreateNotebookFluentBuilder
impl CreateNotebookFluentBuilder
Sourcepub fn as_input(&self) -> &CreateNotebookInputBuilder
pub fn as_input(&self) -> &CreateNotebookInputBuilder
Access the CreateNotebook as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateNotebookOutput, SdkError<CreateNotebookError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateNotebookOutput, SdkError<CreateNotebookError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateNotebookOutput, CreateNotebookError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateNotebookOutput, CreateNotebookError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn domain_identifier(self, input: impl Into<String>) -> Self
pub fn domain_identifier(self, input: impl Into<String>) -> Self
The identifier of the Amazon SageMaker Unified Studio domain in which to create the notebook.
Sourcepub fn set_domain_identifier(self, input: Option<String>) -> Self
pub fn set_domain_identifier(self, input: Option<String>) -> Self
The identifier of the Amazon SageMaker Unified Studio domain in which to create the notebook.
Sourcepub fn get_domain_identifier(&self) -> &Option<String>
pub fn get_domain_identifier(&self) -> &Option<String>
The identifier of the Amazon SageMaker Unified Studio domain in which to create the notebook.
Sourcepub fn owning_project_identifier(self, input: impl Into<String>) -> Self
pub fn owning_project_identifier(self, input: impl Into<String>) -> Self
The identifier of the project that owns the notebook.
Sourcepub fn set_owning_project_identifier(self, input: Option<String>) -> Self
pub fn set_owning_project_identifier(self, input: Option<String>) -> Self
The identifier of the project that owns the notebook.
Sourcepub fn get_owning_project_identifier(&self) -> &Option<String>
pub fn get_owning_project_identifier(&self) -> &Option<String>
The identifier of the project that owns the notebook.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the notebook. The name must be between 1 and 256 characters.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the notebook. The name must be between 1 and 256 characters.
Sourcepub fn get_name(&self) -> &Option<String>
pub fn get_name(&self) -> &Option<String>
The name of the notebook. The name must be between 1 and 256 characters.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the notebook.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the notebook.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the notebook.
Sourcepub fn metadata(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn metadata(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to metadata.
To override the contents of this collection use set_metadata.
The metadata for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
Sourcepub fn set_metadata(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_metadata(self, input: Option<HashMap<String, String>>) -> Self
The metadata for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
Sourcepub fn get_metadata(&self) -> &Option<HashMap<String, String>>
pub fn get_metadata(&self) -> &Option<HashMap<String, String>>
The metadata for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
Sourcepub fn parameters(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn parameters(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to parameters.
To override the contents of this collection use set_parameters.
The sensitive parameters for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
Sourcepub fn set_parameters(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_parameters(self, input: Option<HashMap<String, String>>) -> Self
The sensitive parameters for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
Sourcepub fn get_parameters(&self) -> &Option<HashMap<String, String>>
pub fn get_parameters(&self) -> &Option<HashMap<String, String>>
The sensitive parameters for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.