#[non_exhaustive]pub struct CreateNotebookOutputBuilder { /* private fields */ }Expand description
A builder for CreateNotebookOutput.
Implementations
Sourceimpl CreateNotebookOutputBuilder
impl CreateNotebookOutputBuilder
Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The identifier of the notebook.
This field is required.Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the notebook.
This field is required.Sourcepub fn owning_project_id(self, input: impl Into<String>) -> Self
pub fn owning_project_id(self, input: impl Into<String>) -> Self
The identifier of the project that owns the notebook.
This field is required.Sourcepub fn set_owning_project_id(self, input: Option<String>) -> Self
pub fn set_owning_project_id(self, input: Option<String>) -> Self
The identifier of the project that owns the notebook.
Sourcepub fn get_owning_project_id(&self) -> &Option<String>
pub fn get_owning_project_id(&self) -> &Option<String>
The identifier of the project that owns the notebook.
Sourcepub fn domain_id(self, input: impl Into<String>) -> Self
pub fn domain_id(self, input: impl Into<String>) -> Self
The identifier of the Amazon SageMaker Unified Studio domain.
This field is required.Sourcepub fn set_domain_id(self, input: Option<String>) -> Self
pub fn set_domain_id(self, input: Option<String>) -> Self
The identifier of the Amazon SageMaker Unified Studio domain.
Sourcepub fn get_domain_id(&self) -> &Option<String>
pub fn get_domain_id(&self) -> &Option<String>
The identifier of the Amazon SageMaker Unified Studio domain.
Sourcepub fn cell_order(self, input: CellInformation) -> Self
pub fn cell_order(self, input: CellInformation) -> Self
Appends an item to cell_order.
To override the contents of this collection use set_cell_order.
The ordered list of cells in the notebook.
Sourcepub fn set_cell_order(self, input: Option<Vec<CellInformation>>) -> Self
pub fn set_cell_order(self, input: Option<Vec<CellInformation>>) -> Self
The ordered list of cells in the notebook.
Sourcepub fn get_cell_order(&self) -> &Option<Vec<CellInformation>>
pub fn get_cell_order(&self) -> &Option<Vec<CellInformation>>
The ordered list of cells in the notebook.
Sourcepub fn status(self, input: NotebookStatus) -> Self
pub fn status(self, input: NotebookStatus) -> Self
The status of the notebook.
This field is required.Sourcepub fn set_status(self, input: Option<NotebookStatus>) -> Self
pub fn set_status(self, input: Option<NotebookStatus>) -> Self
The status of the notebook.
Sourcepub fn get_status(&self) -> &Option<NotebookStatus>
pub fn get_status(&self) -> &Option<NotebookStatus>
The status of the notebook.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the notebook.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the notebook.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the notebook.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The timestamp of when the notebook was created.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The timestamp of when the notebook was created.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The timestamp of when the notebook was created.
Sourcepub fn created_by(self, input: impl Into<String>) -> Self
pub fn created_by(self, input: impl Into<String>) -> Self
The identifier of the user who created the notebook.
Sourcepub fn set_created_by(self, input: Option<String>) -> Self
pub fn set_created_by(self, input: Option<String>) -> Self
The identifier of the user who created the notebook.
Sourcepub fn get_created_by(&self) -> &Option<String>
pub fn get_created_by(&self) -> &Option<String>
The identifier of the user who created the notebook.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The timestamp of when the notebook was last updated.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The timestamp of when the notebook was last updated.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The timestamp of when the notebook was last updated.
Sourcepub fn updated_by(self, input: impl Into<String>) -> Self
pub fn updated_by(self, input: impl Into<String>) -> Self
The identifier of the user who last updated the notebook.
Sourcepub fn set_updated_by(self, input: Option<String>) -> Self
pub fn set_updated_by(self, input: Option<String>) -> Self
The identifier of the user who last updated the notebook.
Sourcepub fn get_updated_by(&self) -> &Option<String>
pub fn get_updated_by(&self) -> &Option<String>
The identifier of the user who last updated the notebook.
Sourcepub fn locked_by(self, input: impl Into<String>) -> Self
pub fn locked_by(self, input: impl Into<String>) -> Self
The identifier of the user who locked the notebook.
Sourcepub fn set_locked_by(self, input: Option<String>) -> Self
pub fn set_locked_by(self, input: Option<String>) -> Self
The identifier of the user who locked the notebook.
Sourcepub fn get_locked_by(&self) -> &Option<String>
pub fn get_locked_by(&self) -> &Option<String>
The identifier of the user who locked the notebook.
Sourcepub fn set_locked_at(self, input: Option<DateTime>) -> Self
pub fn set_locked_at(self, input: Option<DateTime>) -> Self
The timestamp of when the notebook was locked.
Sourcepub fn get_locked_at(&self) -> &Option<DateTime>
pub fn get_locked_at(&self) -> &Option<DateTime>
The timestamp of when the notebook was locked.
Sourcepub fn lock_expires_at(self, input: DateTime) -> Self
pub fn lock_expires_at(self, input: DateTime) -> Self
The timestamp of when the notebook lock expires.
Sourcepub fn set_lock_expires_at(self, input: Option<DateTime>) -> Self
pub fn set_lock_expires_at(self, input: Option<DateTime>) -> Self
The timestamp of when the notebook lock expires.
Sourcepub fn get_lock_expires_at(&self) -> &Option<DateTime>
pub fn get_lock_expires_at(&self) -> &Option<DateTime>
The timestamp of when the notebook lock expires.
Sourcepub fn compute_id(self, input: impl Into<String>) -> Self
pub fn compute_id(self, input: impl Into<String>) -> Self
The identifier of the compute associated with the notebook.
Sourcepub fn set_compute_id(self, input: Option<String>) -> Self
pub fn set_compute_id(self, input: Option<String>) -> Self
The identifier of the compute associated with the notebook.
Sourcepub fn get_compute_id(&self) -> &Option<String>
pub fn get_compute_id(&self) -> &Option<String>
The identifier of the compute associated with the notebook.
Sourcepub fn metadata(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn metadata(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to metadata.
To override the contents of this collection use set_metadata.
The metadata of the notebook.
Sourcepub fn set_metadata(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_metadata(self, input: Option<HashMap<String, String>>) -> Self
The metadata of the notebook.
Sourcepub fn parameters(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn parameters(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to parameters.
To override the contents of this collection use set_parameters.
The sensitive parameters of the notebook.
Sourcepub fn set_parameters(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_parameters(self, input: Option<HashMap<String, String>>) -> Self
The sensitive parameters of the notebook.
Sourcepub fn get_parameters(&self) -> &Option<HashMap<String, String>>
pub fn get_parameters(&self) -> &Option<HashMap<String, String>>
The sensitive parameters of the notebook.
Sourcepub fn environment_configuration(self, input: EnvironmentConfig) -> Self
pub fn environment_configuration(self, input: EnvironmentConfig) -> Self
The environment configuration of the notebook.
Sourcepub fn set_environment_configuration(
self,
input: Option<EnvironmentConfig>,
) -> Self
pub fn set_environment_configuration( self, input: Option<EnvironmentConfig>, ) -> Self
The environment configuration of the notebook.
Sourcepub fn get_environment_configuration(&self) -> &Option<EnvironmentConfig>
pub fn get_environment_configuration(&self) -> &Option<EnvironmentConfig>
The environment configuration of the notebook.
Sourcepub fn error(self, input: NotebookError) -> Self
pub fn error(self, input: NotebookError) -> Self
The error details if the notebook creation failed.
Sourcepub fn set_error(self, input: Option<NotebookError>) -> Self
pub fn set_error(self, input: Option<NotebookError>) -> Self
The error details if the notebook creation failed.
Sourcepub fn get_error(&self) -> &Option<NotebookError>
pub fn get_error(&self) -> &Option<NotebookError>
The error details if the notebook creation failed.
Sourcepub fn build(self) -> Result<CreateNotebookOutput, BuildError>
pub fn build(self) -> Result<CreateNotebookOutput, BuildError>
Consumes the builder and constructs a CreateNotebookOutput.
This method will fail if any of the following fields are not set: