#[non_exhaustive]pub struct CreateNotebookInput {
pub domain_identifier: Option<String>,
pub owning_project_identifier: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub metadata: Option<HashMap<String, String>>,
pub parameters: Option<HashMap<String, String>>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_identifier: Option<String>The identifier of the Amazon SageMaker Unified Studio domain in which to create the notebook.
owning_project_identifier: Option<String>The identifier of the project that owns the notebook.
name: Option<String>The name of the notebook. The name must be between 1 and 256 characters.
description: Option<String>The description of the notebook.
metadata: Option<HashMap<String, String>>The metadata for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
parameters: Option<HashMap<String, String>>The sensitive parameters for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
client_token: Option<String>A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
Implementations
Sourceimpl CreateNotebookInput
impl CreateNotebookInput
Sourcepub fn domain_identifier(&self) -> Option<&str>
pub fn domain_identifier(&self) -> Option<&str>
The identifier of the Amazon SageMaker Unified Studio domain in which to create the notebook.
Sourcepub fn owning_project_identifier(&self) -> Option<&str>
pub fn owning_project_identifier(&self) -> Option<&str>
The identifier of the project that owns the notebook.
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
The name of the notebook. The name must be between 1 and 256 characters.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the notebook.
Sourcepub fn metadata(&self) -> Option<&HashMap<String, String>>
pub fn metadata(&self) -> Option<&HashMap<String, String>>
The metadata for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
Sourcepub fn parameters(&self) -> Option<&HashMap<String, String>>
pub fn parameters(&self) -> Option<&HashMap<String, String>>
The sensitive parameters for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
Sourceimpl CreateNotebookInput
impl CreateNotebookInput
Sourcepub fn builder() -> CreateNotebookInputBuilder
pub fn builder() -> CreateNotebookInputBuilder
Creates a new builder-style object to manufacture CreateNotebookInput.