#[non_exhaustive]pub struct GetNotebookOutput {Show 19 fields
pub id: String,
pub name: String,
pub owning_project_id: String,
pub domain_id: String,
pub cell_order: Vec<CellInformation>,
pub status: NotebookStatus,
pub description: Option<String>,
pub created_at: Option<DateTime>,
pub created_by: Option<String>,
pub updated_at: Option<DateTime>,
pub updated_by: Option<String>,
pub locked_by: Option<String>,
pub locked_at: Option<DateTime>,
pub lock_expires_at: Option<DateTime>,
pub compute_id: Option<String>,
pub metadata: Option<HashMap<String, String>>,
pub parameters: Option<HashMap<String, String>>,
pub environment_configuration: Option<EnvironmentConfig>,
pub error: Option<NotebookError>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe identifier of the notebook.
name: StringThe name of the notebook.
owning_project_id: StringThe identifier of the project that owns the notebook.
domain_id: StringThe identifier of the Amazon SageMaker Unified Studio domain.
cell_order: Vec<CellInformation>The ordered list of cells in the notebook.
status: NotebookStatusThe status of the notebook.
description: Option<String>The description of the notebook.
created_at: Option<DateTime>The timestamp of when the notebook was created.
created_by: Option<String>The identifier of the user who created the notebook.
updated_at: Option<DateTime>The timestamp of when the notebook was last updated.
updated_by: Option<String>The identifier of the user who last updated the notebook.
locked_by: Option<String>The identifier of the user who locked the notebook.
locked_at: Option<DateTime>The timestamp of when the notebook was locked.
lock_expires_at: Option<DateTime>The timestamp of when the notebook lock expires.
compute_id: Option<String>The identifier of the compute associated with the notebook.
metadata: Option<HashMap<String, String>>The metadata of the notebook.
parameters: Option<HashMap<String, String>>The sensitive parameters of the notebook.
environment_configuration: Option<EnvironmentConfig>The environment configuration of the notebook.
error: Option<NotebookError>The error details if the notebook is in a failed state.
Implementations
Sourceimpl GetNotebookOutput
impl GetNotebookOutput
Sourcepub fn owning_project_id(&self) -> &str
pub fn owning_project_id(&self) -> &str
The identifier of the project that owns the notebook.
Sourcepub fn cell_order(&self) -> &[CellInformation]
pub fn cell_order(&self) -> &[CellInformation]
The ordered list of cells in the notebook.
Sourcepub fn status(&self) -> &NotebookStatus
pub fn status(&self) -> &NotebookStatus
The status of the notebook.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the notebook.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp of when the notebook was created.
Sourcepub fn created_by(&self) -> Option<&str>
pub fn created_by(&self) -> Option<&str>
The identifier of the user who created the notebook.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The timestamp of when the notebook was last updated.
Sourcepub fn updated_by(&self) -> Option<&str>
pub fn updated_by(&self) -> Option<&str>
The identifier of the user who last updated the notebook.
Sourcepub fn lock_expires_at(&self) -> Option<&DateTime>
pub fn lock_expires_at(&self) -> Option<&DateTime>
The timestamp of when the notebook lock expires.
Sourcepub fn compute_id(&self) -> Option<&str>
pub fn compute_id(&self) -> Option<&str>
The identifier of the compute associated with the notebook.
Sourcepub fn parameters(&self) -> Option<&HashMap<String, String>>
pub fn parameters(&self) -> Option<&HashMap<String, String>>
The sensitive parameters of the notebook.
Sourcepub fn environment_configuration(&self) -> Option<&EnvironmentConfig>
pub fn environment_configuration(&self) -> Option<&EnvironmentConfig>
The environment configuration of the notebook.
Sourcepub fn error(&self) -> Option<&NotebookError>
pub fn error(&self) -> Option<&NotebookError>
The error details if the notebook is in a failed state.
Sourceimpl GetNotebookOutput
impl GetNotebookOutput
Sourcepub fn builder() -> GetNotebookOutputBuilder
pub fn builder() -> GetNotebookOutputBuilder
Creates a new builder-style object to manufacture GetNotebookOutput.