#[non_exhaustive]pub enum GetNotebookRunError {
AccessDeniedException(AccessDeniedException),
InternalServerException(InternalServerException),
ResourceNotFoundException(ResourceNotFoundException),
ThrottlingException(ThrottlingException),
ValidationException(ValidationException),
UnauthorizedException(UnauthorizedException),
Unhandled(Unhandled),
}Expand description
Error type for the GetNotebookRunError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
You do not have sufficient access to perform this action.
InternalServerException(InternalServerException)
The request has failed because of an unknown error, exception or failure.
ResourceNotFoundException(ResourceNotFoundException)
The specified resource cannot be found.
ThrottlingException(ThrottlingException)
The request was denied due to request throttling.
ValidationException(ValidationException)
The input fails to satisfy the constraints specified by the Amazon Web Services service.
You do not have permission to perform this action.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl GetNotebookRunError
impl GetNotebookRunError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the GetNotebookRunError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the GetNotebookRunError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is GetNotebookRunError::AccessDeniedException.
Sourcepub fn is_internal_server_exception(&self) -> bool
pub fn is_internal_server_exception(&self) -> bool
Returns true if the error kind is GetNotebookRunError::InternalServerException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is GetNotebookRunError::ResourceNotFoundException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is GetNotebookRunError::ThrottlingException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is GetNotebookRunError::ValidationException.
Returns true if the error kind is GetNotebookRunError::UnauthorizedException.