#[non_exhaustive]pub struct QueryGraphInput {
pub domain_identifier: Option<String>,
pub match: Option<Vec<MatchClause>>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
pub additional_attributes: Option<AdditionalAttributes>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_identifier: Option<String>The identifier of the Amazon DataZone domain.
match: Option<Vec<MatchClause>>List of query match clauses.
max_results: Option<i32>The maximum number of entities to return in a single call to QueryGraph. When the number of entities to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to QueryGraph to list the next set of entities.
next_token: Option<String>When the number of entities is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of entities, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to QueryGraph to list the next set of entities.
additional_attributes: Option<AdditionalAttributes>Additional details on the queried entity that can be requested in the response.
Implementations
Sourceimpl QueryGraphInput
impl QueryGraphInput
Sourcepub fn domain_identifier(&self) -> Option<&str>
pub fn domain_identifier(&self) -> Option<&str>
The identifier of the Amazon DataZone domain.
Sourcepub fn match(&self) -> &[MatchClause]
pub fn match(&self) -> &[MatchClause]
List of query match clauses.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .r#match.is_none().
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of entities to return in a single call to QueryGraph. When the number of entities to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to QueryGraph to list the next set of entities.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
When the number of entities is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of entities, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to QueryGraph to list the next set of entities.
Sourcepub fn additional_attributes(&self) -> Option<&AdditionalAttributes>
pub fn additional_attributes(&self) -> Option<&AdditionalAttributes>
Additional details on the queried entity that can be requested in the response.
Sourceimpl QueryGraphInput
impl QueryGraphInput
Sourcepub fn builder() -> QueryGraphInputBuilder
pub fn builder() -> QueryGraphInputBuilder
Creates a new builder-style object to manufacture QueryGraphInput.