#[non_exhaustive]pub struct StartNotebookExportOutput {
pub id: String,
pub domain_id: String,
pub owning_project_id: String,
pub notebook_id: String,
pub file_format: FileFormat,
pub status: NotebookExportStatus,
pub created_at: Option<DateTime>,
pub created_by: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe identifier of the notebook export.
domain_id: StringThe identifier of the Amazon SageMaker Unified Studio domain.
owning_project_id: StringThe identifier of the project that owns the notebook.
notebook_id: StringThe identifier of the notebook.
file_format: FileFormatThe file format of the notebook export.
status: NotebookExportStatusThe status of the notebook export.
created_at: Option<DateTime>The timestamp of when the notebook export was started.
created_by: Option<String>The identifier of the user who started the notebook export.
Implementations
Sourceimpl StartNotebookExportOutput
impl StartNotebookExportOutput
Sourcepub fn owning_project_id(&self) -> &str
pub fn owning_project_id(&self) -> &str
The identifier of the project that owns the notebook.
Sourcepub fn notebook_id(&self) -> &str
pub fn notebook_id(&self) -> &str
The identifier of the notebook.
Sourcepub fn file_format(&self) -> &FileFormat
pub fn file_format(&self) -> &FileFormat
The file format of the notebook export.
Sourcepub fn status(&self) -> &NotebookExportStatus
pub fn status(&self) -> &NotebookExportStatus
The status of the notebook export.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp of when the notebook export was started.
Sourcepub fn created_by(&self) -> Option<&str>
pub fn created_by(&self) -> Option<&str>
The identifier of the user who started the notebook export.
Sourceimpl StartNotebookExportOutput
impl StartNotebookExportOutput
Sourcepub fn builder() -> StartNotebookExportOutputBuilder
pub fn builder() -> StartNotebookExportOutputBuilder
Creates a new builder-style object to manufacture StartNotebookExportOutput.