#[non_exhaustive]pub struct StartNotebookImportOutput {
pub notebook_id: Option<String>,
pub status: Option<NotebookStatus>,
pub domain_id: Option<String>,
pub owning_project_id: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub source_location: Option<SourceLocation>,
pub created_at: Option<DateTime>,
pub created_by: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notebook_id: Option<String>The identifier of the imported notebook.
status: Option<NotebookStatus>The status of the notebook import.
domain_id: Option<String>The identifier of the Amazon SageMaker Unified Studio domain.
owning_project_id: Option<String>The identifier of the project that owns the imported notebook.
name: Option<String>The name of the imported notebook.
description: Option<String>The description of the imported notebook.
source_location: Option<SourceLocation>The source location from which the notebook was imported.
created_at: Option<DateTime>The timestamp of when the notebook import was started.
created_by: Option<String>The identifier of the user who started the notebook import.
Implementations
Sourceimpl StartNotebookImportOutput
impl StartNotebookImportOutput
Sourcepub fn notebook_id(&self) -> Option<&str>
pub fn notebook_id(&self) -> Option<&str>
The identifier of the imported notebook.
Sourcepub fn status(&self) -> Option<&NotebookStatus>
pub fn status(&self) -> Option<&NotebookStatus>
The status of the notebook import.
Sourcepub fn domain_id(&self) -> Option<&str>
pub fn domain_id(&self) -> Option<&str>
The identifier of the Amazon SageMaker Unified Studio domain.
Sourcepub fn owning_project_id(&self) -> Option<&str>
pub fn owning_project_id(&self) -> Option<&str>
The identifier of the project that owns the imported notebook.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the imported notebook.
Sourcepub fn source_location(&self) -> Option<&SourceLocation>
pub fn source_location(&self) -> Option<&SourceLocation>
The source location from which the notebook was imported.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp of when the notebook import was started.
Sourcepub fn created_by(&self) -> Option<&str>
pub fn created_by(&self) -> Option<&str>
The identifier of the user who started the notebook import.
Sourceimpl StartNotebookImportOutput
impl StartNotebookImportOutput
Sourcepub fn builder() -> StartNotebookImportOutputBuilder
pub fn builder() -> StartNotebookImportOutputBuilder
Creates a new builder-style object to manufacture StartNotebookImportOutput.