StartNotebookRunOutput

Struct StartNotebookRunOutput 

#[non_exhaustive]
pub struct StartNotebookRunOutput {
Show 22 fields pub id: String, pub domain_id: String, pub owning_project_id: String, pub notebook_id: String, pub schedule_id: Option<String>, pub status: NotebookRunStatus, pub cell_order: Option<Vec<CellInformation>>, pub metadata: Option<HashMap<String, String>>, pub parameters: Option<HashMap<String, String>>, pub compute_configuration: Option<ComputeConfig>, pub network_configuration: Option<NetworkConfig>, pub timeout_configuration: Option<TimeoutConfig>, pub environment_configuration: Option<EnvironmentConfig>, pub storage_configuration: Option<StorageConfig>, pub trigger_source: Option<TriggerSource>, pub error: Option<NotebookRunError>, pub created_at: Option<DateTime>, pub created_by: Option<String>, pub updated_at: Option<DateTime>, pub updated_by: Option<String>, pub started_at: Option<DateTime>, pub completed_at: Option<DateTime>, /* private fields */
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: String

The identifier of the notebook run.

domain_id: String

The identifier of the Amazon DataZone domain.

owning_project_id: String

The identifier of the project that owns the notebook run.

notebook_id: String

The identifier of the notebook.

schedule_id: Option<String>

The identifier of the schedule associated with the notebook run.

status: NotebookRunStatus

The status of the notebook run.

cell_order: Option<Vec<CellInformation>>

The ordered list of cells in the notebook run.

metadata: Option<HashMap<String, String>>

The metadata of the notebook run.

parameters: Option<HashMap<String, String>>

The sensitive parameters of the notebook run.

compute_configuration: Option<ComputeConfig>

The compute configuration of the notebook run.

network_configuration: Option<NetworkConfig>

The network configuration of the notebook run.

timeout_configuration: Option<TimeoutConfig>

The timeout configuration of the notebook run.

environment_configuration: Option<EnvironmentConfig>

The environment configuration of the notebook run, including image version and package settings.

storage_configuration: Option<StorageConfig>

The storage configuration of the notebook run, including the Amazon Simple Storage Service path and KMS key ARN.

trigger_source: Option<TriggerSource>

The source that triggered the notebook run.

error: Option<NotebookRunError>

The error details if the notebook run failed.

created_at: Option<DateTime>

The timestamp of when the notebook run was created.

created_by: Option<String>

The identifier of the user who created the notebook run.

updated_at: Option<DateTime>

The timestamp of when the notebook run was last updated.

updated_by: Option<String>

The identifier of the user who last updated the notebook run.

started_at: Option<DateTime>

The timestamp of when the notebook run started executing.

completed_at: Option<DateTime>

The timestamp of when the notebook run completed.

Implementations

Source

impl StartNotebookRunOutput

pub fn id(&self) -> &str

The identifier of the notebook run.

pub fn domain_id(&self) -> &str

The identifier of the Amazon DataZone domain.

pub fn owning_project_id(&self) -> &str

The identifier of the project that owns the notebook run.

pub fn notebook_id(&self) -> &str

The identifier of the notebook.

pub fn schedule_id(&self) -> Option<&str>

The identifier of the schedule associated with the notebook run.

pub fn status(&self) -> &NotebookRunStatus

The status of the notebook run.

pub fn cell_order(&self) -> &[CellInformation]

The ordered list of cells in the notebook run.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .cell_order.is_none().

pub fn metadata(&self) -> Option<&HashMap<String, String>>

The metadata of the notebook run.

pub fn parameters(&self) -> Option<&HashMap<String, String>>

The sensitive parameters of the notebook run.

pub fn compute_configuration(&self) -> Option<&ComputeConfig>

The compute configuration of the notebook run.

pub fn network_configuration(&self) -> Option<&NetworkConfig>

The network configuration of the notebook run.

pub fn timeout_configuration(&self) -> Option<&TimeoutConfig>

The timeout configuration of the notebook run.

pub fn environment_configuration(&self) -> Option<&EnvironmentConfig>

The environment configuration of the notebook run, including image version and package settings.

pub fn storage_configuration(&self) -> Option<&StorageConfig>

The storage configuration of the notebook run, including the Amazon Simple Storage Service path and KMS key ARN.

pub fn trigger_source(&self) -> Option<&TriggerSource>

The source that triggered the notebook run.

pub fn error(&self) -> Option<&NotebookRunError>

The error details if the notebook run failed.

pub fn created_at(&self) -> Option<&DateTime>

The timestamp of when the notebook run was created.

pub fn created_by(&self) -> Option<&str>

The identifier of the user who created the notebook run.

pub fn updated_at(&self) -> Option<&DateTime>

The timestamp of when the notebook run was last updated.

pub fn updated_by(&self) -> Option<&str>

The identifier of the user who last updated the notebook run.

pub fn started_at(&self) -> Option<&DateTime>

The timestamp of when the notebook run started executing.

pub fn completed_at(&self) -> Option<&DateTime>

The timestamp of when the notebook run completed.

Source

impl StartNotebookRunOutput

pub fn builder() -> StartNotebookRunOutputBuilder

Creates a new builder-style object to manufacture StartNotebookRunOutput.