StartNotebookSyncOutputBuilder

Struct StartNotebookSyncOutputBuilder 

#[non_exhaustive]
pub struct StartNotebookSyncOutputBuilder { /* private fields */ }
A builder for StartNotebookSyncOutput.

Implementations

Source

impl StartNotebookSyncOutputBuilder

pub fn notebook_id(self, input: impl Into<String>) -> Self

The identifier of the synced notebook.

pub fn set_notebook_id(self, input: Option<String>) -> Self

The identifier of the synced notebook.

pub fn get_notebook_id(&self) -> &Option<String>

The identifier of the synced notebook.

pub fn status(self, input: NotebookStatus) -> Self

The status of the notebook sync.

pub fn set_status(self, input: Option<NotebookStatus>) -> Self

The status of the notebook sync.

pub fn get_status(&self) -> &Option<NotebookStatus>

The status of the notebook sync.

pub fn domain_id(self, input: impl Into<String>) -> Self

The identifier of the Amazon SageMaker Unified Studio domain.

pub fn set_domain_id(self, input: Option<String>) -> Self

The identifier of the Amazon SageMaker Unified Studio domain.

pub fn get_domain_id(&self) -> &Option<String>

The identifier of the Amazon SageMaker Unified Studio domain.

pub fn owning_project_id(self, input: impl Into<String>) -> Self

The identifier of the project that owns the synced notebook.

pub fn set_owning_project_id(self, input: Option<String>) -> Self

The identifier of the project that owns the synced notebook.

pub fn get_owning_project_id(&self) -> &Option<String>

The identifier of the project that owns the synced notebook.

pub fn source_location(self, input: SourceLocation) -> Self

The source location from which the notebook was synced.

pub fn set_source_location(self, input: Option<SourceLocation>) -> Self

The source location from which the notebook was synced.

pub fn get_source_location(&self) -> &Option<SourceLocation>

The source location from which the notebook was synced.

pub fn git_metadata(self, input: GitMetadata) -> Self

The Git metadata associated with the synced notebook.

pub fn set_git_metadata(self, input: Option<GitMetadata>) -> Self

The Git metadata associated with the synced notebook.

pub fn get_git_metadata(&self) -> &Option<GitMetadata>

The Git metadata associated with the synced notebook.

pub fn name(self, input: impl Into<String>) -> Self

The name of the synced notebook.

pub fn set_name(self, input: Option<String>) -> Self

The name of the synced notebook.

pub fn get_name(&self) -> &Option<String>

The name of the synced notebook.

pub fn description(self, input: impl Into<String>) -> Self

The description of the synced notebook.

pub fn set_description(self, input: Option<String>) -> Self

The description of the synced notebook.

pub fn get_description(&self) -> &Option<String>

The description of the synced notebook.

pub fn created_at(self, input: DateTime) -> Self

The timestamp of when the notebook sync was started.

pub fn set_created_at(self, input: Option<DateTime>) -> Self

The timestamp of when the notebook sync was started.

pub fn get_created_at(&self) -> &Option<DateTime>

The timestamp of when the notebook sync was started.

pub fn created_by(self, input: impl Into<String>) -> Self

The identifier of the user who started the notebook sync.

pub fn set_created_by(self, input: Option<String>) -> Self

The identifier of the user who started the notebook sync.

pub fn get_created_by(&self) -> &Option<String>

The identifier of the user who started the notebook sync.

pub fn build(self) -> StartNotebookSyncOutput

Consumes the builder and constructs a StartNotebookSyncOutput.