#[non_exhaustive]pub struct StartNotebookSyncOutput {
pub notebook_id: Option<String>,
pub status: Option<NotebookStatus>,
pub domain_id: Option<String>,
pub owning_project_id: Option<String>,
pub source_location: Option<SourceLocation>,
pub git_metadata: Option<GitMetadata>,
pub name: Option<String>,
pub description: Option<String>,
pub created_at: Option<DateTime>,
pub created_by: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notebook_id: Option<String>The identifier of the synced notebook.
status: Option<NotebookStatus>The status of the notebook sync.
domain_id: Option<String>The identifier of the Amazon SageMaker Unified Studio domain.
owning_project_id: Option<String>The identifier of the project that owns the synced notebook.
source_location: Option<SourceLocation>The source location from which the notebook was synced.
git_metadata: Option<GitMetadata>The Git metadata associated with the synced notebook.
name: Option<String>The name of the synced notebook.
description: Option<String>The description of the synced notebook.
created_at: Option<DateTime>The timestamp of when the notebook sync was started.
created_by: Option<String>The identifier of the user who started the notebook sync.
Implementations
Sourceimpl StartNotebookSyncOutput
impl StartNotebookSyncOutput
Sourcepub fn notebook_id(&self) -> Option<&str>
pub fn notebook_id(&self) -> Option<&str>
The identifier of the synced notebook.
Sourcepub fn status(&self) -> Option<&NotebookStatus>
pub fn status(&self) -> Option<&NotebookStatus>
The status of the notebook sync.
Sourcepub fn domain_id(&self) -> Option<&str>
pub fn domain_id(&self) -> Option<&str>
The identifier of the Amazon SageMaker Unified Studio domain.
Sourcepub fn owning_project_id(&self) -> Option<&str>
pub fn owning_project_id(&self) -> Option<&str>
The identifier of the project that owns the synced notebook.
Sourcepub fn source_location(&self) -> Option<&SourceLocation>
pub fn source_location(&self) -> Option<&SourceLocation>
The source location from which the notebook was synced.
Sourcepub fn git_metadata(&self) -> Option<&GitMetadata>
pub fn git_metadata(&self) -> Option<&GitMetadata>
The Git metadata associated with the synced notebook.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the synced notebook.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp of when the notebook sync was started.
Sourcepub fn created_by(&self) -> Option<&str>
pub fn created_by(&self) -> Option<&str>
The identifier of the user who started the notebook sync.
Sourceimpl StartNotebookSyncOutput
impl StartNotebookSyncOutput
Sourcepub fn builder() -> StartNotebookSyncOutputBuilder
pub fn builder() -> StartNotebookSyncOutputBuilder
Creates a new builder-style object to manufacture StartNotebookSyncOutput.