#[non_exhaustive]pub struct StopNotebookRunInput {
pub domain_identifier: Option<String>,
pub identifier: Option<String>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_identifier: Option<String>The identifier of the Amazon DataZone domain in which the notebook run is stopped.
identifier: Option<String>The identifier of the notebook run to stop.
client_token: Option<String>A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
Implementations
Sourceimpl StopNotebookRunInput
impl StopNotebookRunInput
Sourcepub fn domain_identifier(&self) -> Option<&str>
pub fn domain_identifier(&self) -> Option<&str>
The identifier of the Amazon DataZone domain in which the notebook run is stopped.
Sourcepub fn identifier(&self) -> Option<&str>
pub fn identifier(&self) -> Option<&str>
The identifier of the notebook run to stop.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
Sourceimpl StopNotebookRunInput
impl StopNotebookRunInput
Sourcepub fn builder() -> StopNotebookRunInputBuilder
pub fn builder() -> StopNotebookRunInputBuilder
Creates a new builder-style object to manufacture StopNotebookRunInput.