#[non_exhaustive]pub struct StopNotebookRunOutput {
pub id: String,
pub domain_id: String,
pub owning_project_id: String,
pub status: NotebookRunStatus,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe identifier of the notebook run.
domain_id: StringThe identifier of the Amazon SageMaker Unified Studio domain.
owning_project_id: StringThe identifier of the project that owns the notebook run.
status: NotebookRunStatusThe status of the notebook run.
Implementations
Sourceimpl StopNotebookRunOutput
impl StopNotebookRunOutput
Sourcepub fn owning_project_id(&self) -> &str
pub fn owning_project_id(&self) -> &str
The identifier of the project that owns the notebook run.
Sourcepub fn status(&self) -> &NotebookRunStatus
pub fn status(&self) -> &NotebookRunStatus
The status of the notebook run.
Sourceimpl StopNotebookRunOutput
impl StopNotebookRunOutput
Sourcepub fn builder() -> StopNotebookRunOutputBuilder
pub fn builder() -> StopNotebookRunOutputBuilder
Creates a new builder-style object to manufacture StopNotebookRunOutput.