#[non_exhaustive]pub struct AdditionalAttributesBuilder { /* private fields */ }Expand description
A builder for AdditionalAttributes.
Implementations
Sourceimpl AdditionalAttributesBuilder
impl AdditionalAttributesBuilder
Sourcepub fn form_names(self, input: impl Into<String>) -> Self
pub fn form_names(self, input: impl Into<String>) -> Self
Appends an item to form_names.
To override the contents of this collection use set_form_names.
Names of forms on the query entity that can be requested in the response.
Sourcepub fn set_form_names(self, input: Option<Vec<String>>) -> Self
pub fn set_form_names(self, input: Option<Vec<String>>) -> Self
Names of forms on the query entity that can be requested in the response.
Sourcepub fn get_form_names(&self) -> &Option<Vec<String>>
pub fn get_form_names(&self) -> &Option<Vec<String>>
Names of forms on the query entity that can be requested in the response.
Sourcepub fn build(self) -> AdditionalAttributes
pub fn build(self) -> AdditionalAttributes
Consumes the builder and constructs a AdditionalAttributes.