#[non_exhaustive]pub struct EntityPatternBuilder { /* private fields */ }Expand description
A builder for EntityPattern.
Implementations
Sourceimpl EntityPatternBuilder
impl EntityPatternBuilder
Sourcepub fn entity_type(self, input: GraphEntityType) -> Self
pub fn entity_type(self, input: GraphEntityType) -> Self
The type of entity to be matched during the graph query.
This field is required.Sourcepub fn set_entity_type(self, input: Option<GraphEntityType>) -> Self
pub fn set_entity_type(self, input: Option<GraphEntityType>) -> Self
The type of entity to be matched during the graph query.
Sourcepub fn get_entity_type(&self) -> &Option<GraphEntityType>
pub fn get_entity_type(&self) -> &Option<GraphEntityType>
The type of entity to be matched during the graph query.
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The identifier of the root entity to start traversal from during the graph query.
This field is required.Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The identifier of the root entity to start traversal from during the graph query.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The identifier of the root entity to start traversal from during the graph query.
Sourcepub fn filters(self, input: FilterClause) -> Self
pub fn filters(self, input: FilterClause) -> Self
A search filter clause in Amazon DataZone.
Sourcepub fn set_filters(self, input: Option<FilterClause>) -> Self
pub fn set_filters(self, input: Option<FilterClause>) -> Self
A search filter clause in Amazon DataZone.
Sourcepub fn get_filters(&self) -> &Option<FilterClause>
pub fn get_filters(&self) -> &Option<FilterClause>
A search filter clause in Amazon DataZone.
Sourcepub fn build(self) -> Result<EntityPattern, BuildError>
pub fn build(self) -> Result<EntityPattern, BuildError>
Consumes the builder and constructs a EntityPattern.
This method will fail if any of the following fields are not set: