#[non_exhaustive]pub struct NotebookRunSummaryBuilder { /* private fields */ }Expand description
A builder for NotebookRunSummary.
Implementations
Sourceimpl NotebookRunSummaryBuilder
impl NotebookRunSummaryBuilder
Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The identifier of the notebook run.
This field is required.Sourcepub fn domain_id(self, input: impl Into<String>) -> Self
pub fn domain_id(self, input: impl Into<String>) -> Self
The identifier of the Amazon DataZone domain.
This field is required.Sourcepub fn set_domain_id(self, input: Option<String>) -> Self
pub fn set_domain_id(self, input: Option<String>) -> Self
The identifier of the Amazon DataZone domain.
Sourcepub fn get_domain_id(&self) -> &Option<String>
pub fn get_domain_id(&self) -> &Option<String>
The identifier of the Amazon DataZone domain.
Sourcepub fn owning_project_id(self, input: impl Into<String>) -> Self
pub fn owning_project_id(self, input: impl Into<String>) -> Self
The identifier of the project that owns the notebook run.
This field is required.Sourcepub fn set_owning_project_id(self, input: Option<String>) -> Self
pub fn set_owning_project_id(self, input: Option<String>) -> Self
The identifier of the project that owns the notebook run.
Sourcepub fn get_owning_project_id(&self) -> &Option<String>
pub fn get_owning_project_id(&self) -> &Option<String>
The identifier of the project that owns the notebook run.
Sourcepub fn notebook_id(self, input: impl Into<String>) -> Self
pub fn notebook_id(self, input: impl Into<String>) -> Self
The identifier of the notebook.
This field is required.Sourcepub fn set_notebook_id(self, input: Option<String>) -> Self
pub fn set_notebook_id(self, input: Option<String>) -> Self
The identifier of the notebook.
Sourcepub fn get_notebook_id(&self) -> &Option<String>
pub fn get_notebook_id(&self) -> &Option<String>
The identifier of the notebook.
Sourcepub fn schedule_id(self, input: impl Into<String>) -> Self
pub fn schedule_id(self, input: impl Into<String>) -> Self
The identifier of the schedule associated with the notebook run.
Sourcepub fn set_schedule_id(self, input: Option<String>) -> Self
pub fn set_schedule_id(self, input: Option<String>) -> Self
The identifier of the schedule associated with the notebook run.
Sourcepub fn get_schedule_id(&self) -> &Option<String>
pub fn get_schedule_id(&self) -> &Option<String>
The identifier of the schedule associated with the notebook run.
Sourcepub fn status(self, input: NotebookRunStatus) -> Self
pub fn status(self, input: NotebookRunStatus) -> Self
The status of the notebook run.
This field is required.Sourcepub fn set_status(self, input: Option<NotebookRunStatus>) -> Self
pub fn set_status(self, input: Option<NotebookRunStatus>) -> Self
The status of the notebook run.
Sourcepub fn get_status(&self) -> &Option<NotebookRunStatus>
pub fn get_status(&self) -> &Option<NotebookRunStatus>
The status of the notebook run.
Sourcepub fn trigger_source(self, input: TriggerSource) -> Self
pub fn trigger_source(self, input: TriggerSource) -> Self
The source that triggered the notebook run.
Sourcepub fn set_trigger_source(self, input: Option<TriggerSource>) -> Self
pub fn set_trigger_source(self, input: Option<TriggerSource>) -> Self
The source that triggered the notebook run.
Sourcepub fn get_trigger_source(&self) -> &Option<TriggerSource>
pub fn get_trigger_source(&self) -> &Option<TriggerSource>
The source that triggered the notebook run.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The timestamp of when the notebook run was created.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The timestamp of when the notebook run was created.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The timestamp of when the notebook run was created.
Sourcepub fn created_by(self, input: impl Into<String>) -> Self
pub fn created_by(self, input: impl Into<String>) -> Self
The identifier of the user who created the notebook run.
Sourcepub fn set_created_by(self, input: Option<String>) -> Self
pub fn set_created_by(self, input: Option<String>) -> Self
The identifier of the user who created the notebook run.
Sourcepub fn get_created_by(&self) -> &Option<String>
pub fn get_created_by(&self) -> &Option<String>
The identifier of the user who created the notebook run.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The timestamp of when the notebook run was last updated.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The timestamp of when the notebook run was last updated.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The timestamp of when the notebook run was last updated.
Sourcepub fn updated_by(self, input: impl Into<String>) -> Self
pub fn updated_by(self, input: impl Into<String>) -> Self
The identifier of the user who last updated the notebook run.
Sourcepub fn set_updated_by(self, input: Option<String>) -> Self
pub fn set_updated_by(self, input: Option<String>) -> Self
The identifier of the user who last updated the notebook run.
Sourcepub fn get_updated_by(&self) -> &Option<String>
pub fn get_updated_by(&self) -> &Option<String>
The identifier of the user who last updated the notebook run.
Sourcepub fn started_at(self, input: DateTime) -> Self
pub fn started_at(self, input: DateTime) -> Self
The timestamp of when the notebook run started executing.
Sourcepub fn set_started_at(self, input: Option<DateTime>) -> Self
pub fn set_started_at(self, input: Option<DateTime>) -> Self
The timestamp of when the notebook run started executing.
Sourcepub fn get_started_at(&self) -> &Option<DateTime>
pub fn get_started_at(&self) -> &Option<DateTime>
The timestamp of when the notebook run started executing.
Sourcepub fn completed_at(self, input: DateTime) -> Self
pub fn completed_at(self, input: DateTime) -> Self
The timestamp of when the notebook run completed.
Sourcepub fn set_completed_at(self, input: Option<DateTime>) -> Self
pub fn set_completed_at(self, input: Option<DateTime>) -> Self
The timestamp of when the notebook run completed.
Sourcepub fn get_completed_at(&self) -> &Option<DateTime>
pub fn get_completed_at(&self) -> &Option<DateTime>
The timestamp of when the notebook run completed.
Sourcepub fn build(self) -> Result<NotebookRunSummary, BuildError>
pub fn build(self) -> Result<NotebookRunSummary, BuildError>
Consumes the builder and constructs a NotebookRunSummary.
This method will fail if any of the following fields are not set: