#[non_exhaustive]pub struct PackageConfigBuilder { /* private fields */ }Expand description
A builder for PackageConfig.
Implementations
Sourceimpl PackageConfigBuilder
impl PackageConfigBuilder
Sourcepub fn package_manager(self, input: PackageManager) -> Self
pub fn package_manager(self, input: PackageManager) -> Self
The package manager for the notebook run environment. The default value is UV.
Sourcepub fn set_package_manager(self, input: Option<PackageManager>) -> Self
pub fn set_package_manager(self, input: Option<PackageManager>) -> Self
The package manager for the notebook run environment. The default value is UV.
Sourcepub fn get_package_manager(&self) -> &Option<PackageManager>
pub fn get_package_manager(&self) -> &Option<PackageManager>
The package manager for the notebook run environment. The default value is UV.
Sourcepub fn package_specification(self, input: impl Into<String>) -> Self
pub fn package_specification(self, input: impl Into<String>) -> Self
The package specification content for the notebook run environment. The maximum length is 10240 characters.
Sourcepub fn set_package_specification(self, input: Option<String>) -> Self
pub fn set_package_specification(self, input: Option<String>) -> Self
The package specification content for the notebook run environment. The maximum length is 10240 characters.
Sourcepub fn get_package_specification(&self) -> &Option<String>
pub fn get_package_specification(&self) -> &Option<String>
The package specification content for the notebook run environment. The maximum length is 10240 characters.
Sourcepub fn build(self) -> PackageConfig
pub fn build(self) -> PackageConfig
Consumes the builder and constructs a PackageConfig.