#[non_exhaustive]pub struct EntityPattern {
pub entity_type: GraphEntityType,
pub identifier: String,
pub filters: Option<FilterClause>,
}Expand description
The pattern describing the entities to be matched during the graph query.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entity_type: GraphEntityTypeThe type of entity to be matched during the graph query.
identifier: StringThe identifier of the root entity to start traversal from during the graph query.
filters: Option<FilterClause>A search filter clause in Amazon DataZone.
Implementations
Sourceimpl EntityPattern
impl EntityPattern
Sourcepub fn entity_type(&self) -> &GraphEntityType
pub fn entity_type(&self) -> &GraphEntityType
The type of entity to be matched during the graph query.
Sourcepub fn identifier(&self) -> &str
pub fn identifier(&self) -> &str
The identifier of the root entity to start traversal from during the graph query.
Sourcepub fn filters(&self) -> Option<&FilterClause>
pub fn filters(&self) -> Option<&FilterClause>
A search filter clause in Amazon DataZone.
Sourceimpl EntityPattern
impl EntityPattern
Sourcepub fn builder() -> EntityPatternBuilder
pub fn builder() -> EntityPatternBuilder
Creates a new builder-style object to manufacture EntityPattern.