#[non_exhaustive]pub struct GitPropertiesOutput {
pub code_connection_arn: String,
pub repository_id: String,
pub default_branch: String,
pub status: Option<ConnectionStatus>,
pub error_message: Option<String>,
}Expand description
The properties of a Git connection returned by get and list operations, including connection status and any error details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_connection_arn: StringThe ARN of the CodeConnections connection used to connect to the Git repository.
repository_id: StringThe ID of the Git repository. This is the owner and repository name, for example, owner/repo-name.
default_branch: StringThe default branch of the Git repository.
status: Option<ConnectionStatus>The status of the Git connection.
error_message: Option<String>The error message that describes why the Git connection failed. This member is populated when the connection status is CREATE_FAILED or UPDATE_FAILED.
Implementations
Sourceimpl GitPropertiesOutput
impl GitPropertiesOutput
Sourcepub fn code_connection_arn(&self) -> &str
pub fn code_connection_arn(&self) -> &str
The ARN of the CodeConnections connection used to connect to the Git repository.
Sourcepub fn repository_id(&self) -> &str
pub fn repository_id(&self) -> &str
The ID of the Git repository. This is the owner and repository name, for example, owner/repo-name.
Sourcepub fn default_branch(&self) -> &str
pub fn default_branch(&self) -> &str
The default branch of the Git repository.
Sourcepub fn status(&self) -> Option<&ConnectionStatus>
pub fn status(&self) -> Option<&ConnectionStatus>
The status of the Git connection.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
The error message that describes why the Git connection failed. This member is populated when the connection status is CREATE_FAILED or UPDATE_FAILED.
Sourceimpl GitPropertiesOutput
impl GitPropertiesOutput
Sourcepub fn builder() -> GitPropertiesOutputBuilder
pub fn builder() -> GitPropertiesOutputBuilder
Creates a new builder-style object to manufacture GitPropertiesOutput.