#[non_exhaustive]pub struct LineageNodeItem {Show 15 fields
pub domain_id: String,
pub name: Option<String>,
pub description: Option<String>,
pub created_at: Option<DateTime>,
pub created_by: Option<String>,
pub updated_at: Option<DateTime>,
pub updated_by: Option<String>,
pub id: String,
pub type_name: String,
pub type_revision: Option<String>,
pub source_identifier: Option<String>,
pub event_timestamp: Option<DateTime>,
pub forms_output: Option<Vec<FormOutput>>,
pub upstream_lineage_node_ids: Option<Vec<String>>,
pub downstream_lineage_node_ids: Option<Vec<String>>,
}Expand description
The summary and output forms of a LineageNode
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_id: StringThe ID of the domain of the data lineage node.
name: Option<String>The name of the data lineage node.
description: Option<String>The description of the data lineage node.
created_at: Option<DateTime>The timestamp at which the data lineage node was created.
created_by: Option<String>The user who created the data lineage node.
updated_at: Option<DateTime>The timestamp at which the data lineage node was updated.
updated_by: Option<String>The user who updated the data lineage node.
id: StringThe ID of the data lineage node.
type_name: StringThe name of the type of the data lineage node.
type_revision: Option<String>The type of the revision of the data lineage node.
source_identifier: Option<String>The alternate ID of the data lineage node.
event_timestamp: Option<DateTime>The event timestamp of the data lineage node.
forms_output: Option<Vec<FormOutput>>The forms included in the additional attributes of a data lineage node.
upstream_lineage_node_ids: Option<Vec<String>>The IDs of the upstream data lineage nodes.
downstream_lineage_node_ids: Option<Vec<String>>The IDs of the downstream data lineage nodes.
Implementations
Sourceimpl LineageNodeItem
impl LineageNodeItem
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the data lineage node.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp at which the data lineage node was created.
Sourcepub fn created_by(&self) -> Option<&str>
pub fn created_by(&self) -> Option<&str>
The user who created the data lineage node.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The timestamp at which the data lineage node was updated.
Sourcepub fn updated_by(&self) -> Option<&str>
pub fn updated_by(&self) -> Option<&str>
The user who updated the data lineage node.
Sourcepub fn type_revision(&self) -> Option<&str>
pub fn type_revision(&self) -> Option<&str>
The type of the revision of the data lineage node.
Sourcepub fn source_identifier(&self) -> Option<&str>
pub fn source_identifier(&self) -> Option<&str>
The alternate ID of the data lineage node.
Sourcepub fn event_timestamp(&self) -> Option<&DateTime>
pub fn event_timestamp(&self) -> Option<&DateTime>
The event timestamp of the data lineage node.
Sourcepub fn forms_output(&self) -> &[FormOutput]
pub fn forms_output(&self) -> &[FormOutput]
The forms included in the additional attributes of a data lineage node.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .forms_output.is_none().
Sourcepub fn upstream_lineage_node_ids(&self) -> &[String]
pub fn upstream_lineage_node_ids(&self) -> &[String]
The IDs of the upstream data lineage nodes.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .upstream_lineage_node_ids.is_none().
Sourcepub fn downstream_lineage_node_ids(&self) -> &[String]
pub fn downstream_lineage_node_ids(&self) -> &[String]
The IDs of the downstream data lineage nodes.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .downstream_lineage_node_ids.is_none().
Sourceimpl LineageNodeItem
impl LineageNodeItem
Sourcepub fn builder() -> LineageNodeItemBuilder
pub fn builder() -> LineageNodeItemBuilder
Creates a new builder-style object to manufacture LineageNodeItem.