#[non_exhaustive]pub struct LineageSyncInput {
pub timezone: Option<Timezone>,
pub enabled: bool,
pub schedule: Option<String>,
}Expand description
Contains the settings for configuring lineage sync on a Snowflake connection, including the schedule, timezone, and enabled state.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timezone: Option<Timezone>The timezone of the lineage sync schedule.
enabled: boolSpecifies whether lineage sync is enabled.
schedule: Option<String>The schedule of the lineage sync.
Implementations
Sourceimpl LineageSyncInput
impl LineageSyncInput
Sourcepub fn builder() -> LineageSyncInputBuilder
pub fn builder() -> LineageSyncInputBuilder
Creates a new builder-style object to manufacture LineageSyncInput.