#[non_exhaustive]pub struct LineageSyncOutput {
pub lineage_job_id: Option<String>,
pub timezone: Option<Timezone>,
pub enabled: Option<bool>,
pub schedule: Option<String>,
}Expand description
Contains the current state of lineage sync for a Snowflake connection, including the schedule, timezone, enabled state, and the ID of the associated lineage job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.lineage_job_id: Option<String>The ID of the lineage sync job.
timezone: Option<Timezone>The timezone of the lineage sync schedule.
enabled: Option<bool>Specifies whether lineage sync is enabled.
schedule: Option<String>The schedule of the lineage sync.
Implementations
Sourceimpl LineageSyncOutput
impl LineageSyncOutput
Sourcepub fn lineage_job_id(&self) -> Option<&str>
pub fn lineage_job_id(&self) -> Option<&str>
The ID of the lineage sync job.
Sourceimpl LineageSyncOutput
impl LineageSyncOutput
Sourcepub fn builder() -> LineageSyncOutputBuilder
pub fn builder() -> LineageSyncOutputBuilder
Creates a new builder-style object to manufacture LineageSyncOutput.