#[non_exhaustive]pub struct NetworkConfig {
pub network_access_type: NetworkAccessType,
pub vpc_id: Option<String>,
pub subnet_ids: Option<Vec<String>>,
pub security_group_ids: Option<Vec<String>>,
}Expand description
The network configuration for a notebook run in Amazon DataZone.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.network_access_type: NetworkAccessTypeThe network access type for the notebook run. Valid values are PUBLIC_INTERNET_ONLY and VPC_ONLY.
vpc_id: Option<String>The identifier of the VPC for the notebook run. This is required when the network access type is VPC_ONLY.
subnet_ids: Option<Vec<String>>The identifiers of the subnets for the notebook run. You can specify up to 10 subnets.
security_group_ids: Option<Vec<String>>The identifiers of the security groups for the notebook run. You can specify up to 5 security groups.
Implementations
Sourceimpl NetworkConfig
impl NetworkConfig
Sourcepub fn network_access_type(&self) -> &NetworkAccessType
pub fn network_access_type(&self) -> &NetworkAccessType
The network access type for the notebook run. Valid values are PUBLIC_INTERNET_ONLY and VPC_ONLY.
Sourcepub fn vpc_id(&self) -> Option<&str>
pub fn vpc_id(&self) -> Option<&str>
The identifier of the VPC for the notebook run. This is required when the network access type is VPC_ONLY.
Sourcepub fn subnet_ids(&self) -> &[String]
pub fn subnet_ids(&self) -> &[String]
The identifiers of the subnets for the notebook run. You can specify up to 10 subnets.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .subnet_ids.is_none().
Sourcepub fn security_group_ids(&self) -> &[String]
pub fn security_group_ids(&self) -> &[String]
The identifiers of the security groups for the notebook run. You can specify up to 5 security groups.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .security_group_ids.is_none().
Sourceimpl NetworkConfig
impl NetworkConfig
Sourcepub fn builder() -> NetworkConfigBuilder
pub fn builder() -> NetworkConfigBuilder
Creates a new builder-style object to manufacture NetworkConfig.