#[non_exhaustive]pub struct PackageConfig {
pub package_manager: PackageManager,
pub package_specification: Option<String>,
}Expand description
The package configuration for a notebook run environment in Amazon DataZone.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.package_manager: PackageManagerThe package manager for the notebook run environment. The default value is UV.
package_specification: Option<String>The package specification content for the notebook run environment. The maximum length is 10240 characters.
Implementations
Sourceimpl PackageConfig
impl PackageConfig
Sourcepub fn package_manager(&self) -> &PackageManager
pub fn package_manager(&self) -> &PackageManager
The package manager for the notebook run environment. The default value is UV.
Sourcepub fn package_specification(&self) -> Option<&str>
pub fn package_specification(&self) -> Option<&str>
The package specification content for the notebook run environment. The maximum length is 10240 characters.
Sourceimpl PackageConfig
impl PackageConfig
Sourcepub fn builder() -> PackageConfigBuilder
pub fn builder() -> PackageConfigBuilder
Creates a new builder-style object to manufacture PackageConfig.