#[non_exhaustive]pub struct ProjectMembershipAssignment {
pub member: Option<Member>,
pub designation: UserDesignation,
}Expand description
A map of user or group profiles to designations that need to be assigned in the project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.member: Option<Member>The details about a project member.
designation: UserDesignationThe designation of the project membership.
Implementations
Sourceimpl ProjectMembershipAssignment
impl ProjectMembershipAssignment
Sourcepub fn designation(&self) -> &UserDesignation
pub fn designation(&self) -> &UserDesignation
The designation of the project membership.
Sourceimpl ProjectMembershipAssignment
impl ProjectMembershipAssignment
Sourcepub fn builder() -> ProjectMembershipAssignmentBuilder
pub fn builder() -> ProjectMembershipAssignmentBuilder
Creates a new builder-style object to manufacture ProjectMembershipAssignment.