#[non_exhaustive]pub struct SnowflakePropertiesInput {
pub connectivity_properties: Option<ConnectivityProperties>,
pub snowflake_role: String,
pub identity_mapping: Option<IdentityMapping>,
pub lineage_sync: Option<LineageSyncInput>,
}Expand description
Contains the Snowflake-specific settings required when creating or updating a connection, including the Snowflake role, identity mapping, and lineage sync configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connectivity_properties: Option<ConnectivityProperties>The connectivity properties of the Snowflake connection.
snowflake_role: StringThe Snowflake role used to access Snowflake resources.
identity_mapping: Option<IdentityMapping>The identity mapping configuration for the Snowflake connection.
lineage_sync: Option<LineageSyncInput>The lineage sync configuration for the Snowflake connection.
Implementations
Sourceimpl SnowflakePropertiesInput
impl SnowflakePropertiesInput
Sourcepub fn connectivity_properties(&self) -> Option<&ConnectivityProperties>
pub fn connectivity_properties(&self) -> Option<&ConnectivityProperties>
The connectivity properties of the Snowflake connection.
Sourcepub fn snowflake_role(&self) -> &str
pub fn snowflake_role(&self) -> &str
The Snowflake role used to access Snowflake resources.
Sourcepub fn identity_mapping(&self) -> Option<&IdentityMapping>
pub fn identity_mapping(&self) -> Option<&IdentityMapping>
The identity mapping configuration for the Snowflake connection.
Sourcepub fn lineage_sync(&self) -> Option<&LineageSyncInput>
pub fn lineage_sync(&self) -> Option<&LineageSyncInput>
The lineage sync configuration for the Snowflake connection.
Sourceimpl SnowflakePropertiesInput
impl SnowflakePropertiesInput
Sourcepub fn builder() -> SnowflakePropertiesInputBuilder
pub fn builder() -> SnowflakePropertiesInputBuilder
Creates a new builder-style object to manufacture SnowflakePropertiesInput.