#[non_exhaustive]pub struct SnowflakePropertiesOutput {
pub snowflake_role: String,
pub identity_mapping: Option<IdentityMapping>,
pub lineage_sync: Option<LineageSyncOutput>,
pub status: ConnectionStatus,
pub error_message: Option<String>,
}Expand description
Contains the Snowflake-specific settings returned for an existing connection, including the current role, identity mapping, lineage sync state, and connection status.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.snowflake_role: StringThe Snowflake role used to access Snowflake resources.
identity_mapping: Option<IdentityMapping>The identity mapping configuration for the Snowflake connection.
lineage_sync: Option<LineageSyncOutput>The lineage sync configuration for the Snowflake connection.
status: ConnectionStatusThe status of the Snowflake connection.
error_message: Option<String>An error message returned if the Snowflake connection failed to establish or validate.
Implementations
Sourceimpl SnowflakePropertiesOutput
impl SnowflakePropertiesOutput
Sourcepub fn snowflake_role(&self) -> &str
pub fn snowflake_role(&self) -> &str
The Snowflake role used to access Snowflake resources.
Sourcepub fn identity_mapping(&self) -> Option<&IdentityMapping>
pub fn identity_mapping(&self) -> Option<&IdentityMapping>
The identity mapping configuration for the Snowflake connection.
Sourcepub fn lineage_sync(&self) -> Option<&LineageSyncOutput>
pub fn lineage_sync(&self) -> Option<&LineageSyncOutput>
The lineage sync configuration for the Snowflake connection.
Sourcepub fn status(&self) -> &ConnectionStatus
pub fn status(&self) -> &ConnectionStatus
The status of the Snowflake connection.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
An error message returned if the Snowflake connection failed to establish or validate.
Sourceimpl SnowflakePropertiesOutput
impl SnowflakePropertiesOutput
Sourcepub fn builder() -> SnowflakePropertiesOutputBuilder
pub fn builder() -> SnowflakePropertiesOutputBuilder
Creates a new builder-style object to manufacture SnowflakePropertiesOutput.