#[non_exhaustive]pub struct StorageConfig {
pub project_s3_path: Option<String>,
pub kms_key_arn: Option<String>,
}Expand description
The storage configuration for a notebook run in Amazon DataZone.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_s3_path: Option<String>The Amazon Simple Storage Service path for the project storage.
kms_key_arn: Option<String>The ARN of the KMS key used for encryption.
Implementations
Sourceimpl StorageConfig
impl StorageConfig
Sourcepub fn project_s3_path(&self) -> Option<&str>
pub fn project_s3_path(&self) -> Option<&str>
The Amazon Simple Storage Service path for the project storage.
Sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
The ARN of the KMS key used for encryption.
Sourceimpl StorageConfig
impl StorageConfig
Sourcepub fn builder() -> StorageConfigBuilder
pub fn builder() -> StorageConfigBuilder
Creates a new builder-style object to manufacture StorageConfig.