#[non_exhaustive]pub struct StartNotebookRunInput {
pub domain_identifier: Option<String>,
pub owning_project_identifier: Option<String>,
pub notebook_identifier: Option<String>,
pub schedule_identifier: Option<String>,
pub compute_configuration: Option<ComputeConfig>,
pub network_configuration: Option<NetworkConfig>,
pub timeout_configuration: Option<TimeoutConfig>,
pub trigger_source: Option<TriggerSource>,
pub metadata: Option<HashMap<String, String>>,
pub parameters: Option<HashMap<String, String>>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_identifier: Option<String>The identifier of the Amazon DataZone domain in which the notebook run is started.
owning_project_identifier: Option<String>The identifier of the project that owns the notebook run.
notebook_identifier: Option<String>The identifier of the notebook to run.
schedule_identifier: Option<String>The identifier of the schedule associated with the notebook run.
compute_configuration: Option<ComputeConfig>The compute configuration for the notebook run, including instance type and environment version.
network_configuration: Option<NetworkConfig>The network configuration for the notebook run, including network access type and optional VPC settings.
timeout_configuration: Option<TimeoutConfig>The timeout configuration for the notebook run. The default timeout is 720 minutes (12 hours) and the maximum is 1440 minutes (24 hours).
trigger_source: Option<TriggerSource>The source that triggered the notebook run.
metadata: Option<HashMap<String, String>>The metadata for the notebook run, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
parameters: Option<HashMap<String, String>>The sensitive parameters for the notebook run, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
client_token: Option<String>A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
Implementations
Sourceimpl StartNotebookRunInput
impl StartNotebookRunInput
Sourcepub fn domain_identifier(&self) -> Option<&str>
pub fn domain_identifier(&self) -> Option<&str>
The identifier of the Amazon DataZone domain in which the notebook run is started.
Sourcepub fn owning_project_identifier(&self) -> Option<&str>
pub fn owning_project_identifier(&self) -> Option<&str>
The identifier of the project that owns the notebook run.
Sourcepub fn notebook_identifier(&self) -> Option<&str>
pub fn notebook_identifier(&self) -> Option<&str>
The identifier of the notebook to run.
Sourcepub fn schedule_identifier(&self) -> Option<&str>
pub fn schedule_identifier(&self) -> Option<&str>
The identifier of the schedule associated with the notebook run.
Sourcepub fn compute_configuration(&self) -> Option<&ComputeConfig>
pub fn compute_configuration(&self) -> Option<&ComputeConfig>
The compute configuration for the notebook run, including instance type and environment version.
Sourcepub fn network_configuration(&self) -> Option<&NetworkConfig>
pub fn network_configuration(&self) -> Option<&NetworkConfig>
The network configuration for the notebook run, including network access type and optional VPC settings.
Sourcepub fn timeout_configuration(&self) -> Option<&TimeoutConfig>
pub fn timeout_configuration(&self) -> Option<&TimeoutConfig>
The timeout configuration for the notebook run. The default timeout is 720 minutes (12 hours) and the maximum is 1440 minutes (24 hours).
Sourcepub fn trigger_source(&self) -> Option<&TriggerSource>
pub fn trigger_source(&self) -> Option<&TriggerSource>
The source that triggered the notebook run.
Sourcepub fn metadata(&self) -> Option<&HashMap<String, String>>
pub fn metadata(&self) -> Option<&HashMap<String, String>>
The metadata for the notebook run, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
Sourcepub fn parameters(&self) -> Option<&HashMap<String, String>>
pub fn parameters(&self) -> Option<&HashMap<String, String>>
The sensitive parameters for the notebook run, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
Sourceimpl StartNotebookRunInput
impl StartNotebookRunInput
Sourcepub fn builder() -> StartNotebookRunInputBuilder
pub fn builder() -> StartNotebookRunInputBuilder
Creates a new builder-style object to manufacture StartNotebookRunInput.