#[non_exhaustive]pub struct StartNotebookSyncOutputBuilder { /* private fields */ }Expand description
A builder for StartNotebookSyncOutput.
Implementations
Sourceimpl StartNotebookSyncOutputBuilder
impl StartNotebookSyncOutputBuilder
Sourcepub fn notebook_id(self, input: impl Into<String>) -> Self
pub fn notebook_id(self, input: impl Into<String>) -> Self
The identifier of the synced notebook.
Sourcepub fn set_notebook_id(self, input: Option<String>) -> Self
pub fn set_notebook_id(self, input: Option<String>) -> Self
The identifier of the synced notebook.
Sourcepub fn get_notebook_id(&self) -> &Option<String>
pub fn get_notebook_id(&self) -> &Option<String>
The identifier of the synced notebook.
Sourcepub fn status(self, input: NotebookStatus) -> Self
pub fn status(self, input: NotebookStatus) -> Self
The status of the notebook sync.
Sourcepub fn set_status(self, input: Option<NotebookStatus>) -> Self
pub fn set_status(self, input: Option<NotebookStatus>) -> Self
The status of the notebook sync.
Sourcepub fn get_status(&self) -> &Option<NotebookStatus>
pub fn get_status(&self) -> &Option<NotebookStatus>
The status of the notebook sync.
Sourcepub fn domain_id(self, input: impl Into<String>) -> Self
pub fn domain_id(self, input: impl Into<String>) -> Self
The identifier of the Amazon SageMaker Unified Studio domain.
Sourcepub fn set_domain_id(self, input: Option<String>) -> Self
pub fn set_domain_id(self, input: Option<String>) -> Self
The identifier of the Amazon SageMaker Unified Studio domain.
Sourcepub fn get_domain_id(&self) -> &Option<String>
pub fn get_domain_id(&self) -> &Option<String>
The identifier of the Amazon SageMaker Unified Studio domain.
Sourcepub fn owning_project_id(self, input: impl Into<String>) -> Self
pub fn owning_project_id(self, input: impl Into<String>) -> Self
The identifier of the project that owns the synced notebook.
Sourcepub fn set_owning_project_id(self, input: Option<String>) -> Self
pub fn set_owning_project_id(self, input: Option<String>) -> Self
The identifier of the project that owns the synced notebook.
Sourcepub fn get_owning_project_id(&self) -> &Option<String>
pub fn get_owning_project_id(&self) -> &Option<String>
The identifier of the project that owns the synced notebook.
Sourcepub fn source_location(self, input: SourceLocation) -> Self
pub fn source_location(self, input: SourceLocation) -> Self
The source location from which the notebook was synced.
Sourcepub fn set_source_location(self, input: Option<SourceLocation>) -> Self
pub fn set_source_location(self, input: Option<SourceLocation>) -> Self
The source location from which the notebook was synced.
Sourcepub fn get_source_location(&self) -> &Option<SourceLocation>
pub fn get_source_location(&self) -> &Option<SourceLocation>
The source location from which the notebook was synced.
Sourcepub fn git_metadata(self, input: GitMetadata) -> Self
pub fn git_metadata(self, input: GitMetadata) -> Self
The Git metadata associated with the synced notebook.
Sourcepub fn set_git_metadata(self, input: Option<GitMetadata>) -> Self
pub fn set_git_metadata(self, input: Option<GitMetadata>) -> Self
The Git metadata associated with the synced notebook.
Sourcepub fn get_git_metadata(&self) -> &Option<GitMetadata>
pub fn get_git_metadata(&self) -> &Option<GitMetadata>
The Git metadata associated with the synced notebook.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the synced notebook.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the synced notebook.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the synced notebook.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The timestamp of when the notebook sync was started.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The timestamp of when the notebook sync was started.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The timestamp of when the notebook sync was started.
Sourcepub fn created_by(self, input: impl Into<String>) -> Self
pub fn created_by(self, input: impl Into<String>) -> Self
The identifier of the user who started the notebook sync.
Sourcepub fn set_created_by(self, input: Option<String>) -> Self
pub fn set_created_by(self, input: Option<String>) -> Self
The identifier of the user who started the notebook sync.
Sourcepub fn get_created_by(&self) -> &Option<String>
pub fn get_created_by(&self) -> &Option<String>
The identifier of the user who started the notebook sync.
Sourcepub fn build(self) -> StartNotebookSyncOutput
pub fn build(self) -> StartNotebookSyncOutput
Consumes the builder and constructs a StartNotebookSyncOutput.